#!/usr/bin/perl -w
#
# Perl script example using DNS
#
# Written by Nicolai Langfeldt, May 2000 for inclusion in the book
# "The Concise guide to DNS and BIND" published by MCP.
#
# This code is in the Public Domain.  Use it as you wish. Neither
# Nicolai Langfeldt or MCP can be held liable for any consequences of
# its use in any context.

use Socket;

sub do_lookup {
    my($host)=shift;
    # Check cache first
    if (exists($address{$host})) {
	# We know the address already
	$thataddr=$address{$host};
    } else {
	# Cache miss, get and remember.
	(my $fqdn, undef, undef, undef, $thataddr) = gethostbyname($host);
	# Hostname lookup failure?  Cache the miss.
	if (defined($fqdn)) {
	    $address{$host}=$thataddr;
	    $address{$fqdn}=$thataddr if $fqdn ne $host;
	} else {
	    $thataddr=$address{$host}=undef;
	}
    }  
    if ($thataddr) {
	print "$host resolves to ",inet_ntoa($thataddr),"\n";
    } else {
	print "$host does not resolve\n";
    }
}

do_lookup("www.amazon.com");
do_lookup("lala.amazon.com");
do_lookup("www.linpro.no");

